Module insights

Module insights 

Insights and metrics endpoints.

Functions

get_available_account_insight_metrics
Returns available account insight metric names as string slices.
get_available_follower_demographics_breakdowns
Returns available follower demographics breakdown names as string slices.
get_available_insight_periods
Returns available insight period names as string slices.
get_available_post_insight_metrics
Returns available post insight metric names as string slices.