Error types and helpers.
Structs
- Base
Fields - Base fields extracted from any typed error variant.
Enums
- Error
- All error variants returned by the Threads API client.
Functions
- extract_
base_ fields - Extract common base fields from a typed error variant.
Returns
NoneforHttpandJsonvariants. - new_
api_ error - Create a new generic API error.
- new_
authentication_ error - Create a new authentication error.
- new_
network_ error - Create a new network error without an underlying cause.
- new_
network_ error_ with_ cause - Create a new network error wrapping an underlying reqwest cause.
- new_
rate_ limit_ error - Create a new rate-limit error.
- new_
validation_ error - Create a new validation error.
- set_
error_ metadata - Set transient flag, HTTP status code, and error subcode on a typed error.
Type Aliases
- Result
- Alias for
std::result::Result<T, Error>.